@@ -1,4 +1,5 @@
 from copy import deepcopy
+from enum import Enum
 
 
 def remove_key(value: dict, removed_key='self') -> dict:
@@ -16,6 +17,9 @@ def package_data(dict_data: dict, replace_keys: dict = None) -> dict:
     for k, v in dict_data.items():
         if v is None:
             new_dict.pop(k)
+            continue
+        if isinstance(v, Enum):
+            new_dict[k] = v.value
         if k in replace_keys:
             new_dict[replace_keys[k]] = new_dict.pop(k)
     return new_dict
