@@ -1262,6 +1262,23 @@ class AsyncClient(BaseClient):
         data = package_data(remove_key(locals()))
         return await self._request_coin_margined_private_api("post", "swap_matchresults", data=data)
 
+    async def coin_margined_order_history(self, contract_code, trade_type, type, status, create_date=90, page_index=1,
+                                          page_size=20, sort_by="create_date"):
+        """
+        获取合约历史委托
+
+        contract_code	true	string	合约代码	支持大小写,"BTC-USD" ...
+        trade_type	true	int	交易类型	0:全部,1:买入开多,2: 卖出开空,3: 买入平空,4: 卖出平多,5: 卖出强平,6: 买入强平,7:交割平多,8: 交割平空, 11:减仓平多，12:减仓平空
+        type	true	int	类型	1:所有订单,2:结束状态的订单
+        status	true	string	订单状态	可查询多个状态，"3,4,5" , 0:全部,3:未成交, 4: 部分成交,5: 部分成交已撤单,6: 全部成交,7:已撤单
+        create_date	true	int	日期	可随意输入正整数，如果参数超过90则默认查询90天的数据
+        page_index	false	int		页码，不填默认第1页	1
+        page_size	false	int	每页条数，不填默认20	20	[1-50]
+        sort_by false string 排序字段，默认create_date降序
+        """
+        data = package_data(remove_key(locals()))
+        return await self._request_coin_margined_private_api("post", "swap_hisorders", data=data)
+
     async def coin_margined_lightning_close_position(self, contract_code, volume, direction, client_order_id=None,
                                                      order_price_type=constants.OrderPriceType.LIGHTNING):
         """
