@@ -76,8 +76,8 @@ class ReconnectingWebSocket:
         """
         self._url = url
         self.url_path = urlparse(url).path[1:]
-        self.ws: aiohttp.ClientWebSocketResponse = None
-        self._session: aiohttp.ClientSession = None
+        self.ws: Optional[aiohttp.ClientWebSocketResponse] = None
+        self._session: Optional[aiohttp.ClientSession] = None
         self._conn = None
         self._proxy = proxy
         self._auto_ping = auto_ping
@@ -180,6 +180,8 @@ class ReconnectingWebSocket:
                 await self.recv()
             self.auth_complete_event.set()
             logging.debug("auth complete!")
+        for payload in self._sub_channels:
+            await self.ws.send_json(payload)
 
     async def check_connection(self, *args, **kwargs):
         if not self.ws:
@@ -281,6 +283,16 @@ class ReconnectingWebSocket:
         logging.debug(f"send msg: {payload}")
         await self.ws.send_json(payload)
 
+    async def sub(self, payload):
+        if payload not in self._sub_channels:
+            self._sub_channels.append(payload)
+        await self.send_request(payload)
+
+    async def unsub(self, payload):
+        if payload in self._sub_channels:
+            self._sub_channels.remove(payload)
+        await self.send_request(payload)
+
 
 class HuoBiWebSocketManager:
     BASE_URL = "wss://api.hbdm.com/"
